package org.jtheque.primary.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.JThequeDao;
import org.jtheque.primary.od.BorrowerImpl;

import java.util.List;

/**
 * A DAO for borrowers specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoBorrowers extends JThequeDao {
    String TABLE = "T_BORROWERS";

    /**
     * Cette mthode retourne la liste complte des emprunteurs de la base de donnes. Si la liste est nulle, on va
     * chercher dans la base de donnes tous les emprunteurs.
     *
     * @return All the borrowers
     */
    List<BorrowerImpl> getBorrowers();

    /**
     * Cette mthode permet de rcuprer un emprunteur dans la base de donnes en fonction de son id.
     *
     * @param id L'id de l'emprunteur
     * @return L'emprunteur correspondant  l'id
     */
    BorrowerImpl getBorrower(int id);

    /**
     * Create a new borrower.
     *
     * @param borrower The new borrower
     */
    void create(BorrowerImpl borrower);

    /**
     * Save the borrower.
     *
     * @param borrower The borrower to save.
     */
    void save(BorrowerImpl borrower);

    /**
     * Cette mthode permet de supprimmer un emprunteur.
     *
     * @param borrower L'emprunteur  supprimmer
     * @return true if the object is deleted else false.
     */
    boolean delete(BorrowerImpl borrower);
}