package org.jtheque.primary.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.JThequeDao;
import org.jtheque.primary.od.CountryImpl;

import java.util.List;

/**
 * A DAO for countries specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoCountries extends JThequeDao {
    String TABLE = "T_COUNTRIES";

    /**
     * Cette mthode retourne l'ensemble des pays du programme.
     *
     * @return La liste des pays
     */
    List<CountryImpl> getCountries();

    /**
     * Cette mthode permet de rcuprer un pays  partir de son ID. Si les pays ne sont pas encore monts en
     * RAM, on le fait.
     *
     * @param id L'id du pays  rcuprer
     * @return Le pays qui correspond  cet ID
     */
    CountryImpl getCountry(int id);

    /**
     * Cette mthode permet de rcuprer un pays dans la base de donnes en fonction de son nom.
     *
     * @param text Le nom du pays
     * @return Le pays correspondant au nom
     */
    CountryImpl getCountry(String text);

    /**
     * Indicate if the country exist in the Dao.
     *
     * @param country The country we must test if it's exist.
     * @return <code>true</code> if the country exist else <code>false</code>.
     */
    boolean exist(CountryImpl country);

    /**
     * Cette mthode permet de supprimmer un pays.
     *
     * @param country Le pays  supprimmer
     * @return true if the object is deleted else false.
     */
    boolean delete(CountryImpl country);

    /**
     * Cette mthode permet d'ajouter un nouveau pays.
     *
     * @param country The country to create
     */
    void create(CountryImpl country);

    /**
     * Save the country on the database.
     *
     * @param country The country to save.
     */
    void save(CountryImpl country);
}