package org.jtheque.primary.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.JThequeDao;
import org.jtheque.primary.od.LanguageImpl;

import java.util.List;

/**
 * A DAO for languages specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoLanguages extends JThequeDao {
    String TABLE = "T_LANGUAGES";

    /**
     * Cette mthode retourne l'ensemble des langues du programme.
     *
     * @return La liste des langues
     */
    List<LanguageImpl> getLanguages();

    /**
     * Cette mthode permet de rcuprer une langue  partir de son ID. Si les langues ne sont pas encore monts
     * en RAM, on le fait.
     *
     * @param id L'id de la langue  rcuprer
     * @return La langue qui correspond  cet ID
     */
    LanguageImpl getLanguage(int id);

    /**
     * Cette mthode permet de rcuprer une langue dans la base de donnes en fonction de son nom.
     *
     * @param text Le nom de la langue
     * @return La langue correspondant au nom
     */
    LanguageImpl getLanguage(String text);

    /**
     * Indicate if the language exist in the Dao.
     *
     * @param language The language we must test if it's exist.
     * @return <code>true</code> if the language exist else <code>false</code>.
     */
    boolean exist(LanguageImpl language);

    /**
     * Create a new language.
     *
     * @param langue The language to create
     */
    void create(LanguageImpl langue);

    /**
     * Cette mthode permet de mettre  jour les infos dans la DB.
     *
     * @param langue The language to save
     */
    void save(LanguageImpl langue);

    /**
     * Cette mthode permet de supprimmer une langue.
     *
     * @param langue La langue  supprimmer
     * @return true if the object is deleted else false.
     */
    boolean delete(LanguageImpl langue);
}