package org.jtheque.primary.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.TypeImpl;
import org.jtheque.core.managers.persistence.able.JThequeDao;

import java.util.List;

/**
 * A DAO for types specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoTypes extends JThequeDao {
    String TABLE = "T_TYPES";

    /**
     * Return all the types.
     *
     * @return A List containing all the types.
     */
    List<TypeImpl> getTypes();

    /**
     * Return the type with the specified ID.
     *
     * @param id The ID of the searched type.
     * @return The type.
     */
    TypeImpl getType(int id);

    /**
     * Return the type with the specified name.
     *
     * @param name The searched name.
     * @return The type.
     */
    TypeImpl getType(String name);

    /**
     * Save the type.
     *
     * @param type The type to save.
     */
    void save(TypeImpl type);

    /**
     * Create the type.
     *
     * @param type The type to create.
     */
    void create(TypeImpl type);

    /**
     * Delete the type.
     *
     * @param type The type to delete.
     * @return true if the object is deleted else false.
     */
    boolean delete(TypeImpl type);

    boolean exists(TypeImpl type);
}