package org.jtheque.primary.od;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.abstraction.Borrower;
import org.jtheque.utils.EqualsUtils;
import org.jtheque.utils.Constants;

/**
 * Cette classe reprsente un emprunteur et toutes ses donnes.
 *
 * @author Baptiste Wicht
 */
public final class BorrowerImpl extends Borrower {
    @Override
    public String getAffichableText() {
        return getFirstName() + ' ' + getName();
    }

    @Override
    public String toString() {
        return getAffichableText();
    }

    @Override
    public int hashCode() {
        int result = Constants.HASH_CODE_START;

        result = Constants.HASH_CODE_PRIME * result + (getEmail() == null ? 0 : getEmail().hashCode());
        result = Constants.HASH_CODE_PRIME * result + getId();
        result = Constants.HASH_CODE_PRIME * result + (getName() == null ? 0 : getName().hashCode());
        result = Constants.HASH_CODE_PRIME * result + (getFirstName() == null ? 0 : getFirstName().hashCode());

        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if(EqualsUtils.areObjectIncompatible(this, obj)){
            return false;
        }

        final Borrower other = (Borrower) obj;

        if(EqualsUtils.areNotEquals(getEmail(), other.getEmail())){
            return false;
        }

        if(EqualsUtils.areNotEquals(getId(), other.getId())){
            return false;
        }

        if(EqualsUtils.areNotEquals(getName(), other.getName())){
            return false;
        }

        return !EqualsUtils.areNotEquals(getFirstName(), other.getFirstName());
    }
}