package org.jtheque.primary.od.abstraction;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.abstraction.Data;

/**
 * A collection of films.
 *
 * @author Baptiste Wicht
 */
public abstract class Collection extends PrimaryData {
    // Collections parameter
    private String title;
    private boolean protection;
    private String password;

    /**
     * Set the title of the collection
     *
     * @param title The collection's title.
     */
    public final void setTitle(String title) {
        this.title = title;
    }

    /**
     * Return the title of the collection.
     *
     * @return The title of the collection.
     */
    public final String getTitle() {
        return title;
    }

    /**
     * Indicate if the collection is password protected or not.
     *
     * @return true if the collection is password protected else false.
     */
    public final boolean isProtection() {
        return protection;
    }

    /**
     * Set a boolean flag indicating if the collection is password-protected or not.
     *
     * @param protection A boolean flag indicating if the collection is password-protected or not.
     */
    public final void setProtection(boolean protection) {
        this.protection = protection;
    }

    /**
     * Return the password of the collection encrypted with SHA-256.
     *
     * @return The encrypted password.
     */
    public final String getPassword() {
        return password;
    }

    /**
     * Set the password of the collection.
     *
     * @param password The password of the collection.
     */
    public final void setPassword(String password) {
        this.password = password;
    }
}