package org.jtheque.primary.od.abstraction;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.utils.bean.IntDate;
import org.jtheque.primary.od.BorrowerImpl;

/**
 * An abstract lending.
 *
 * @author Baptiste Wicht
 */
public abstract class Lending extends PrimaryData {
    private IntDate date;
    private BorrowerImpl theBorrower;
    private int theOther;

    /**
     * Set the date of the lending.
     *
     * @param date The date of the lending.
     */
    public final void setDate(IntDate date) {
        this.date = date;
    }

    /**
     * Return the date of the lending.
     *
     * @return The date.
     */
    public final IntDate getDate() {
        return date;
    }

    /**
     * Set the borrower.
     *
     * @param theBorrower The borrower.
     */
    public final void setTheBorrower(BorrowerImpl theBorrower) {
        this.theBorrower = theBorrower;
    }

    /**
     * Return the borrower of the lending.
     *
     * @return The borrower of the lending.
     */
    public final BorrowerImpl getTheBorrower() {
        return theBorrower;
    }

    /**
     * Set the other of the lending.
     *
     * @param other The other of the lending.
     */
    public final void setTheOther(int other) {
        this.theOther = other;
    }

    /**
     * Return the other.
     *
     * @return The other.
     */
    public final int getTheOther() {
        return theOther;
    }
}