package org.jtheque.primary.services.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.KindImpl;
import org.jtheque.core.managers.persistence.able.DataContainer;

import java.util.List;

/**
 * A kinds service specification.
 *
 * @author Baptiste Wicht
 */
public interface IKindsService extends DataContainer<KindImpl> {
    String DATA_TYPE = "Kinds";

    /**
     * Return the default kind.
     *
     * @return The default kind.
     */
    KindImpl getDefaultKind();

    /**
     * Return the kinds.
     *
     * @return A List containing all the kinds.
     */
    List<KindImpl> getKinds();

    /**
     * Create the kind.
     *
     * @param kind The kind to create.
     */
    void create(KindImpl kind);

    /**
     * Delete the kind.
     *
     * @param kind The kind to delete.
     * @return true if the kind has been deleted.
     */
    boolean delete(KindImpl kind);

    /**
     * Save the kind.
     *
     * @param kind The kind to save.
     */
    void save(KindImpl kind);

    /**
     * Return the kind with the name.
     *
     * @param name The name to search form.
     * @return The searched kind.
     */
    KindImpl getKind(String name);

    /**
     * Indicate if exists a kind with the name.
     *
     * @param name The name of the kind.
     * @return true if the kind exists else false.
     */
    boolean exists(String name);

    boolean exists(KindImpl kind);

    boolean hasNoKinds();

    void createAll(Iterable<KindImpl> kinds);
}