package org.jtheque.primary.services.able;

import org.jtheque.primary.od.LendingImpl;
import org.jtheque.core.managers.persistence.able.DataContainer;

import java.util.List;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * A lendings service specification.
 *
 * @author Baptiste Wicht
 */
public interface ILendingsService extends DataContainer<LendingImpl> {
    String DATA_TYPE = "Lendings";

    /**
     * Return the lending with this id.
     *
     * @param id The id to search the kind with.
     * @return The lending.
     */
    LendingImpl getLending(int id);

    /**
     * Indicate if there is no lendings.
     *
     * @return true if there is no lendings else false.
     */
    boolean hasNoLendings();

    /**
     * Return all the lendings.
     *
     * @return A List containing all the lendings.
     */
    List<LendingImpl> getLendings();

    /**
     * Save the lending.
     *
     * @param lending The lending to save.
     */
    void save(LendingImpl lending);

    /**
     * Delete a lending.
     *
     * @param lending The lending to delete.
     * @return true if the lending has been deleted.
     */
    boolean delete(LendingImpl lending);

    /**
     * Create a lending.
     *
     * @param lending The lending to create.
     */
    void create(LendingImpl lending);

    boolean isLate(LendingImpl lending, int days);
}