package org.jtheque.primary.services.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.core.managers.persistence.able.AbstractDataContainer;
import org.jtheque.primary.dao.able.IDaoLanguages;
import org.jtheque.primary.od.LanguageImpl;
import org.jtheque.primary.services.able.ILanguagesService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;


/**
 * A languages service implementation.
 *
 * @author Baptiste Wicht
 */
@Service
public final class LanguagesService extends AbstractDataContainer<LanguageImpl> implements ILanguagesService {
    @Resource
    private IDaoLanguages daoLanguages;

    /* Variables */
    private LanguageImpl defaultLanguage;

    @Override
    public LanguageImpl getDefaultLanguage() {
        if (defaultLanguage == null) {
            defaultLanguage = daoLanguages.getLanguage("Franais");

            if (defaultLanguage == null) {
                createDefaultLanguage();
            }
        }

        return defaultLanguage;
    }

    /**
     * Create the default language.
     */
    @Transactional
    private void createDefaultLanguage() {
        defaultLanguage = new LanguageImpl();

        defaultLanguage.setName("Franais");
        daoLanguages.create(defaultLanguage);
    }

    @Override
    public List<LanguageImpl> getDatas() {
        return daoLanguages.getLanguages();
    }

    @Override
    public void addDataListener(DataListener listener) {
        daoLanguages.addDataListener(listener);
    }

    @Override
    @Transactional
    public void create(LanguageImpl language) {
        daoLanguages.create(language);
    }

    @Override
    @Transactional
    public boolean delete(LanguageImpl language) {
        return daoLanguages.delete(language);
    }

    @Override
    @Transactional
    public void save(LanguageImpl language) {
        daoLanguages.save(language);
    }

    @Override
    public LanguageImpl getLanguage(String name) {
        return daoLanguages.getLanguage(name);
    }

    @Override
    public boolean exist(LanguageImpl language) {
        return daoLanguages.exist(language);
    }

    @Override
    @Transactional
    public void createAll(Iterable<LanguageImpl> languages) {
        for (LanguageImpl language : languages) {
            daoLanguages.create(language);
        }
    }

    @Override
    public List<LanguageImpl> getLanguages() {
        return daoLanguages.getLanguages();
    }

    @Override
    @Transactional
    public void clearAll() {
        daoLanguages.clearAll();
    }

    @Override
    public String getDataType() {
        return DATA_TYPE;
    }
}