package org.jtheque.primary.view.impl.frames;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.od.abstraction.Country;
import org.jtheque.primary.view.able.ICountryView;
import org.jtheque.primary.view.impl.models.CountryModel;

import javax.swing.JTextField;
import javax.annotation.PostConstruct;

import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/**
 * Cette classe est la classe d'interface graphique permettant d'ajouter ou de modifier un pays.
 *
 * @author Baptiste Wicht
 */
public final class CountryView extends SwingDialogView implements ICountryView {
    private static final long serialVersionUID = -3525319522701158262L;

    private JTextField fieldNom;

    private JThequeAction validateAction;
    private JThequeAction closeAction;
    
    /**
     * Constructeur utilis pour ajouter un nouveau pays.
     * 
     * @param frame The parent frame. 
     */
    public CountryView(Frame frame) {
        super(frame);
    }

    /**
     * Cettte mthode permet de vider tous les champs pour faire un nouvel ajout.
     */
    @Override
    public void reload() {
        setTitleKey("country.view.title");

        fieldNom.setText("");

        getModel().setCountry(null);
    }

    @Override
    public void reload(Data data) {
        Country pays = (Country) data;

        setTitle(getMessage("country.view.title.modify") + pays.getName());

        fieldNom.setText(pays.getName());

        getModel().setCountry(pays);
    }

    @Override
    @PostConstruct
    public void build() {
        setContentPane(buildContentPane());
        setResizable(true);
        pack();
        
        reload();

        SwingUtils.centerFrame(this);
    }

    /**
     * Cette mthode initialise et retourne le contentPane de la fentre.
     *
     * @return Le contentPane
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();
        
        builder.addI18nLabel("country.view.name", builder.gbcSet(0, 0));
        
        fieldNom = builder.add(new JTextField(15), builder.gbcSet(1, 0));
        SwingUtils.addFieldValidateAction(fieldNom, validateAction);
        SwingUtils.addFieldLenghtLimit(fieldNom, 50);

        builder.addButtonBar(builder.gbcSet(0, 1, GridBagUtils.HORIZONTAL, GridBagUtils.BASELINE_LEADING, 2, 1), validateAction, closeAction);
        
        return builder.getPanel();
    }

    @Override
    public JTextField getFieldNom() {
        return fieldNom;
    }

    @Override
    public CountryModel getModel() {
        return (CountryModel) super.getModel();
    }

    @Override
    public void refreshText() {
        if (getModel().getCountry() != null) {
            setTitle(getMessage("borrower.view.title.edit") + getModel().getCountry().getName());
        }
    }

    @Override
    protected void validate(List<JThequeError> jThequeErrors) {
        //Nothing to do
    }

    /**
     * Set the action to launch the validate the view. This is not for use, this only for Spring Injection. 
     * 
     * @param validateAction The action. 
     */
    public void setValidateAction(JThequeAction validateAction) {
        this.validateAction = validateAction;
    }

    /**
     * Set the action to launch the close the view. This is not for use, this only for Spring Injection. 
     * 
     * @param closeAction The action. 
     */
    public void setCloseAction(JThequeAction closeAction) {
        this.closeAction = closeAction;
    }
}