package org.jtheque.primary.view.impl.models;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.event.WeakEventListenerList;
import org.jtheque.core.managers.persistence.DataEvent;
import org.jtheque.core.managers.persistence.Entity;
import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.core.managers.view.able.components.IModel;
import org.jtheque.primary.view.impl.listeners.CurrentObjectListener;
import org.jtheque.primary.view.impl.listeners.DisplayListListener;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;

import java.util.List;

/**
 * A model for the princpal data.
 *
 * @author Baptiste Wicht
 */
public abstract class PrincipalDataModel implements IModel, DataListener {
    private final WeakEventListenerList listenerList;

    /**
     * Construct a new PrincipalDataModel.
     */
    public PrincipalDataModel() {
        super();

        listenerList = new WeakEventListenerList();
    }

    /**
     * Return the event listener list.
     *
     * @return The event listener list.
     */
    protected final WeakEventListenerList getEventListenerList() {
        return listenerList;
    }

    /**
     * Cette mthode permet d'ajouter un nouveau listener  la classe.
     *
     * @param listener Le nouveau listener
     */
    public final void addCurrentObjectListener(CurrentObjectListener listener) {
        listenerList.add(CurrentObjectListener.class, listener);
    }

    /**
     * Cette mthode enleve un listener de la classe.
     *
     * @param listener Le listener  enlever
     */
    public final void removeCurrentObjectListner(CurrentObjectListener listener) {
        listenerList.remove(CurrentObjectListener.class, listener);
    }

    /**
     * Add a display list listener.
     *
     * @param listener The listener.
     */
    public final void addDisplayListListener(DisplayListListener listener) {
        listenerList.add(DisplayListListener.class, listener);
    }

    /**
     * Remove a display list listener.
     *
     * @param listener The listener.
     */
    public final void removeDisplayListListener(DisplayListListener listener) {
        listenerList.remove(DisplayListListener.class, listener);
    }

    /**
     * Cette mthode permet d'avertir tous les listeners que l'objet courant a chang.
     *
     * @param event The event to fire
     */
    protected final void fireCurrentObjectChanged(ObjectChangedEvent event) {
        CurrentObjectListener[] listeners = listenerList.getListeners(CurrentObjectListener.class);

        for (CurrentObjectListener listener : listeners) {
            listener.objectChanged(event);
        }
    }

    /**
     * Avert the listeners that the display list have changed.
     */
    protected final void fireDisplayListChanged() {
        DisplayListListener[] listeners = listenerList.getListeners(DisplayListListener.class);

        for (DisplayListListener listener : listeners) {
            listener.displayListChanged();
        }
    }

    @Override
    public final void dataChanged(DataEvent e) {
        updateDisplayList();
    }

    /**
     * Update the displaylist and replace his datas with a new list.
     *
     * @param datas The new display list.
     */
    public abstract void updateDisplayList(List<? extends Entity> datas);

    /**
     * Update the display list.
     */
    public abstract void updateDisplayList();
}