package org.jtheque.primary.view.impl.sort;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.util.ArrayList;
import java.util.List;

/**
 * Cette classe est la factory des Sorter.
 *
 * @author Baptiste Wicht
 */
public final class SorterFactory {
    private final List<Sorter> sorters;

    private static final SorterFactory INSTANCE = new SorterFactory();

    /**
     * Construit un nouvel objet SorterFactory et initialise les diffrents Sorters.
     */
    private SorterFactory() {
        super();

        sorters = new ArrayList<Sorter>(10);
    }

    /**
     * Return the unique instance of the class.
     *
     * @return The singleton of the class.
     */
    public static SorterFactory getInstance() {
        return INSTANCE;
    }

    /**
     * Add a sorter to manage.
     *
     * @param sorter The sorter to add.
     */
    public void addSorter(Sorter sorter) {
        sorters.add(sorter);
    }

    /**
     * Remove a sorter to manage.
     *
     * @param sorter The sorter to remove.
     */
    public void removeSorter(Sorter sorter) {
        sorters.remove(sorter);
    }

    /**
     * Retourne un sorter pour le type de contenu et le type de tri.
     *
     * @param content  Le type de contenu
     * @param sortType Le type de tri
     * @return The sorter of the specified or <code>null</code> if no sorter of this type exist.
     */
    public Sorter getSorter(String content, String sortType) {
        for (Sorter sorter : sorters) {
            if (sorter.canSort(content, sortType)) {
                return sorter;
            }
        }

        return null;
    }
}
